


''******************************************
''*  Sea Scout Propeller-Shaft Monitor     *
''*  Author: Gregg Erickson  2011          *
''*  See MIT License for Related Copyright *
''*  See end of file and objects for .     *
''*  related copyrights and terms of use   *
''*                                        *
''*  This used code from and based on:     *
''*  Graphics Demo by Chip Gracey 2005     *
''*  TV Object by Chip Gracey 2004         *
''*  Motor_Minder by Tom Doylee 2007       *
''*  Numbers by Jeff Marten 2005           *
''*  Updated Clock by Jeff Marten 2005/201 *
''*  EEPROM -Parallax PE Kit               *
''*  Simple Serial - Chip Gracey, Phil     *
''*  Pilgrim, Jon Williams,JeffMartin 2006 *
''*  Software RTC by Jon McPhalen          *
''*  RCTIME - Andy Lindsay 2010            *
''*  Memsic 2125 Driver-Beau Schawb 2006/09*
''*  and other Parallax Inc & Forum Demos  *
''******************************************

{  This program was written to monitor and display the speed, direction and wear of twin counter rotating
propeller shafts, each driven by an 600 horsepower diesel engine on an 82 foot Point Class Cutter built in
1963 by the Coast Guard and used as a Navy missile retriever.   It also simultaneously monitors the ships pitch and
roll as well as detecting the presence of water in six watertight compartments and in drip pans under the propeller
shafts should water leak in at the shaft seals.  Temperature sensors monitor the temperature of the shaft packing seals to ensure they don't overheat due to friction from over tightening or failure to loosen under operation.

This program reads two pair of Melexis 90217 Hall sensors via a modified version of "motor_minder" to read
propeller shaft rotation and direction based upon a count of pulses and period (in milliseconds) between pulses.
The RPM calculation routine uses combined booleans of pulses detected and a timeout variable in a case selection
to deal with calculation exceptions where only the first pulse is detected, a second pulse is anticipated but
may or may not come and where it has been too long since the last pulse. In addition to rotations speed (rpm)
and pulses (revolutions), the code determines the direction of the shaft rotation by using the second hall sensor
to determine if the second hall sensor is triggered during the falling edge trigger of the first sensor which
only happens is one direction of rotation consistent with a rotary encoder configuration. A modified version
of the motor_minder object counts pulses using counters A and B and add results to objects in the main
memory and outputs in both positive and negative pulse lengths to reflect rotation direction.

The results are them displayed using the Graphics Object. Updates are written then copied to the video memory but
can be directly written to avoid memory limitations.  Each gauge can be moved around the screen by adjusting the locations in the constants.  The prop gauges have a moving needle and large numbers for RPM and the number of revolutions displayed like an odometer.  The results are also sent out via a serial port to a second prop for additional displays. And to an original mechanical gauge.

The program uses eight cogs. The first cog [0] runs the control program, bilge monitoring. Clock speed and a numbers
conversion object. The second [1] runs the TV object, the third [2] runs the graphics engine, the fourth [3] runs an attitude sensor, the fifth [4] runs a real time clock emulator, the sixth [5] monitors the port shaft monitor (modified motor minder),
the seventh [5] runs the starboard shaft monitor.   Integer math is used to reduce overhead and provide adequate accuracy.

## Issue to be resolved / tested
   # Zero Memsic, always leaves a few degrees expectial on Y
   # Calibrate Thermistors
   # Test under full loads and Check Amp Usage

Subsequent improvements could include


   * Simplify Variables
   * Re-add RPM Balance Gauge
   * Add "Ship's Listing" method with Average, Rates, etc.
   * Add Max, Min, Average for Thermisters
   * Add support for a servo to make minor adjustments in speed for balance.
   * MultiProgram Bootloading to Attitude, Clock etc..

COG and Hardware Pin Assignments are listed below:


COGs
0 Main     - Control Program, Serial, Gauge Output, Clock Speed, Bilge Monitor
1 TV       - Send Out NTSC Video Signals to TV
2 Graphics - Drawing Graphics and Put in Memory for TV
3 Realtime clock - Estimates elapsed time
4 Memsic   - Monitor X&Y Attitude through Memsic
5 Motor_M  - Monitor Port RPMs, Etc
6 Motor_M  - Monitor StarBoard RPMs, Etc


BILGE SENSORS & LED INDICATOR
( Connected to LED through 1.1 K resistor and to Input through another 1.1K resistorin series
0 Bilge - Chain Locker (Digital Input & LED Output)
1 Bilge - Forward Crew (Digital Input & LED Output)
2 Bilge - Galley (Digital Input & LED Output)
3 Bilge - Engine Room (Digital Input & LED Output)
4 Bilge - Aft Crew (Digital Input & LED Output)
5 Bilge - Lazerette (Digital Input & LED Output)

6 Bilge - Port Shaft (Digital Input & LED Output)
7 Bilge - Starboard Shaft (Digital Input & LED Output)

SERIAL COMMUNICATIONS
8 SerialPort - Receive (Rx)
9 SerialPort - Transmit(Tx)

ATTITUDE SENSOR
10 Attitude Sensor - Memsic 2125 Raw X Tilt (PWM Input)through 220 Ohm Resistor
11 Attitude Sensor - Memsic 2125 Ras Y Tilt (PWM Input)through 220 Ohm Resistor

VIDEO & SOUND
12 Video - Digital Out through 1.1K ohm resistor
13 Video - Digital Out through 560 ohm resistor
14 Video - Digital Out through 220 ohm resistor
15 Audio - (Piezo Disc)

TACHOMETER INPUT
16 Tachometer 1 - Port Speed ( Melexis 90217 Hall Sensor) through sensor protection circuit board
17 Tachometer 1 - Port Direction ( Melexis 90217 Hall Sensor)through sensor protection circuit board
18 Tachometer 2 - Starboard Speed ( Melexis 90217 Hall Sensor)through sensor protection circuit board
19 Tachometer 2 - Starboard Direction ( Melexis 90217 Hall Sensor)through sensor protection circuit board

TACHOMETER OUTPUT
20 Starboard Differential Duty Cycle Pin
21 Starboard Differential Duty Cycle Pin
22 Port Differential Duty Cycle Pin
23 Port Differential Duty Cycle Pin

THERMISTOR INPUT
24 Port 10K Thermister in parallel with 10 nF Capacitor through 100 ohm resistor
25 Starboard 10K Thermister in parallel with 10 nF Capacitor through 100 ohm resistor

UNASSIGNED PINS
26 Hibernate Signal
27 TBD

BOARD DEFAULT PINS
28 EEPROM Clock
29 EEPROM Data
30 Serial Rx - Receive
31 Serial Tx - Transmit

Vss      ground
Vdd      3.3 Volt
Vin      5 volt for melexis


 }

CON


                                      ' ---- Spin Constants --------
  _clkmode = xtal1 + pll16x           ' Set clock mode to 16x the speed of the crystal
  _xinfreq = 5_000_000                ' Define crystal speed at 5M so clockspeed is 5x16 or 80 Mhz
  _stack = ($4000 +342) >> 2          ' Set Stack large enough for display and variables


  x_tiles = 16                        ' Define tiles for video memory used for mapping
  y_tiles = 12                        ' Define tiles for video memory used for mapping    
  paramcount = 14                     ' Define parameter count to pass to the TV object
  display_base = $5000                ' Location of video memory passed to TV


                                      '---- Constants for Video Display -----------------
                                     
  PortX  =-70                         ' Port Gauge X Location
  PortY=   37                         ' Port Gauge Y Location
  PortR=   57                         ' Port Gauge Radius, e.g. diameter
  StarX=   70                         ' Starboard Gauge X Location
  StarY=   37                         ' Starboard Gauge Y Location
  StarR=   57                         ' Starboard Gauge Radius, e.g. diameter
  TitleX=  0                          ' Title X Location
  TitleY=  91                         ' Title Y Location
  Scale=   4                          ' Number x 200 = Maximum Gauge Scale
  GaugeScale=16_777_216               ' 2?? 256


                  ' ---- Constants for Pins -------
  SGaugePinB = 20        'Output Pin to Gauge
  SGaugePinA = 21        'Output Pin to Gauge
  PGaugePinB = 22        'Output Pin to Gauge
  PGaugePinA = 23        'Output Pin to Gauge
  SThermPin  = 24        'Input Pin from Thermistor
  PThermPin  = 25        'Input Pin from Thermistor


               ' ---- Constants for Program -------
  Magnets = 1            'Number of Magnets per revolution



VAR

  Long  XTilt, YTilt                  ' Initial value of memsic X & Y
                                      ' ----- Pulse Variables --------------

  Long  SPeriod,    PPeriod          ' Measured Time between Pulses From Motorminder used to Calculation RPMs
  Long  SPulseCount,PPulseCount      ' Count of Hall Sensor Pulses from Motor Minder used to Calculate Revolutions
  Long  SSavedCount,PSavedCount      ' Saved Count of Pulses representing revolutions
  Long  SExpiration,PExpiration      ' Calculated Clock Count when time out will occur
  Long  SLastPulse, PLastPulse       ' Clock when last pulse came in - for calculating estimated RPM

                                      ' ------ Pulse Status Variables moved to Start Method for Faster Execution -------                                     

                                       '----Variables for Revolution Count and RPM Calculation
  
  Long  StarRPM, PortRPM              ' Calculated Starboard RPM, Port RPM accounting for pulses per rotation, etc.    
  Long  SLastRPM, PLastRPM            ' Last RPM as limit for estimated RPM
  Long  StarRevs, PortRevs            ' Calculated Revolutions of Shaft accounting for pulses per rotation, etc.
  Long  OldStarRPM,OldPortRPM         ' Saved values for clearing Screen
                                      '-------Variables for Bilge & Transmission Calculation   

  Byte  SReverse, PReverse            ' Boolean indicating if negative shaft rotation at time of pulse
  Byte  SGear,PGear                   ' Transmission Direction Status,   -1=reverse, 0=stopped, 1=forward
  Byte  SSavedGear,PSavedGear         ' Saved Transmission Direction Status,   -1=reverse, 0=stopped, 1=forward  
  Long  SShiftCount,PShiftCount       ' Count changes between neutral, forward and reverse
  Byte  Bilge_Alarm                   ' Bilge Status for up to 6 bilges [5..0] and two drip pans [7..6]


                                       '------- Variable for TV Output -------------------

  long  tv_status                      '0/1/2 = off/visible/invisible           read-only
  long  tv_enable                      '0/? = off/on                            write-only
  long  tv_pins                        '%ppmmm = pins                           write-only
  long  tv_mode                        '%ccinp = chroma,interlace,ntsc/pal,swap write-only
  long  tv_screen                      'pointer to screen (words)               write-only
  long  tv_colors                      'pointer to colors (longs)               write-only
  long  tv_hc                          'horizontal cells                        write-only
  long  tv_vc                          'vertical cells                          write-only
  long  tv_hx                          'horizontal cell expansion               write-only
  long  tv_vx                          'vertical cell expansion                 write-only
  long  tv_ho                          'horizontal offset                       write-only
  long  tv_vo                          'vertical offset                         write-only
  long  tv_broadcast                   'broadcast frequency (Hz)                write-only
  long  tv_auralcog                    'aural fm cog                            write-only

                                       ' --------Variables for Graphics ---------
                                       
  word  screen[x_tiles * y_tiles]      ' graphics tiles
  long  colors[64]                     ' color variables
  long  i, dx, dy                      ' index counters used to initialize graphics

                                       ' ------- Operational Variables

  byte  packet[56]                     ' Long x Revs X 2 = 8 bytes
  byte  p                              ' Long x RPM  x 2 = 8 bytes
                                       ' Long x Shifts x 2 = 8 bytes
                                       ' Alarms x 1 = 1 byte
                                         '  total 25 bytes
  byte Ptemp,Stemp
  long  mytimer[5]                     ' Elapsed Timer Variable


OBJ                                    ' Other Spin Objects servicing main program with 4 cogs
                                       ' The main program operates in the first cog with tv, graphics and motorminder x 2 launching new cogs

  tv    : "tv"                         ' Display Output to TV
  gr    : "graphics"                   ' Create Graphics for Display
  NuCon : "Numbers2"                   ' Create string bytes for display
  serial: "FullDuplexSerial"              ' Share data with second Propeller



PUB start |  PCaseByte,SCaseByte, PExpired, PPulseDetected, SExpired, SPulseDetected,PTherm,STherm

 
                   '-----------Start TV Object and point to the address of the TV variables ---

  longmove(@tv_status, @tvparams, paramcount)
  tv_screen := @screen
  tv_colors := @colors
  tv.start(@tv_status)

                         '---------- initialize colors ----------------
  repeat i from 0 to 63
'
'                  Text
'                  |  Dial
'                  |  |  Needle
'                  |  |  |  Background
'                  |  |  |  |
    colors[i] := $4b_AC_06_02         ' use 3=text,2=dial,1=needle,0=background

                                 '------- Initilize Tile Screen ---------
  repeat dx from 0 to tv_hc - 1
    repeat dy from 0 to tv_vc - 1
      screen[dy * tv_hc + dx] := display_base >> 6 + dy + dx * tv_vc + ((dy & $3F) << 10)

                                 '------- Start Graphics,Numbers, Serial,Clock-----
gr.start                                    'Start Graphic object
gr.setup(16, 12, 128, 96, display_base)     'Setup Graphics and point to video memory used
NuCon.init                                  'Start Numbers conversion object
serial[0].start(9,8,0,9600)                    'start Serial Communication
'serial[1].start(31,30,0,9600)                    'start Serial Communication



                  '--
                        ' Setup Starboard Gauge
frqa :=128*gaugescale         ' Set ctra duty cycle default
ctra[30..26] := %00111        ' Set ctra to differential dutymode
ctra[14..9] := SGaugePinB     ' Set ctra's BPIN
ctra[5..0] := SGaugePinA      ' Set ctra's APIN
dira[SGaugePinB]~~            ' Set Gauge Pin to output
dira[SGaugePinA]~~            ' Set Gauge Pin to output

                        ' Setup Port Gauge
frqb :=128*gaugescale         ' Set ctrb duty cycle default
ctrb[30..26] := %00111        ' Set ctrb to differential dutymode
ctrb[14..9] := PGaugePinB     ' Set ctrb's BPIN
ctrb[5..0] := PGaugePinA      ' Set ctrb's APIN
dira[PGaugePinB]~~            ' Set Gauge Pin to output
dira[PGaugePinA]~~            ' Set Gauge Pin to output


    '-----------Draw Static Titles ---------------------
    'draw title box
    gr.textmode(1,1,6,5)          'Set text properties
    gr.colorwidth(2,0)            'Set text color and width
    gr.text(TitleX,TitleY,@pitch) 'Write Pitch Label
    gr.text(TitleX,-40,@roll)     'Write Roll Label


    '----------Draw Static Part of Gauges ------------------------------
    '(note: 1 degree is about 23 ticks for angle calculation ) ----------

    gr.color(2)
    gr.arc(PortX,PortY,PortR,PortR,0,23,360,0)           'Draw Port Dial Dial
    gr.arc(StarX,StarY,StarR,StarR,0,23,360,0)           'Draw Starboard Dial
    repeat i from -100 to 200 step 10
      gr.arc(PortX,PortY,PortR,PortR,23*i,23,1,0)        'Draw Port Rotational Ticks
      gr.arc(PortX,PortY,PortR-5,PortR-5,23*i,23,1,1)
      gr.arc(StarX,StarY,StarR,StarR,23*i,23,1,0)        'Draw Starbard Rotational Ticks
      gr.arc(StarX,StarY,StarR-5,StarR-5,23*i,23,1,1)
      if i//50==0
        gr.arc(PortX,PortY,PortR,PortR,23*i,23,1,0)      'Draw Port Large Ticks
        gr.arc(PortX,PortY,PortR-10,PortR-10,23*i,23,1,1)
        gr.arc(StarX,StarY,StarR,StarR,23*i,23,1,0)      'Draw Starboard Large Tick
        gr.arc(StarX,StarY,StarR-10,StarR-10,23*i,23,1,1)



Repeat          '--------- Run Main Control Loop ----------





    ' ---------------- Check Bilges, Temp, Runtime, RPM  ------

     '---------------- Check Runtime -----------
    
     '-------------- Package and Transmit Serial Packets to Other Locations


      packet[0]:=serial[0].rx           'Pull byte
 '      serial[1].tx(packet[0])
      if packet[0]==10                  'If character is $A then maybe ending so
         packet[0]:=serial[0].rx        'pull another character to look for $D
  '       serial[1].tx(packet[0])
         if packet[0]==13
           repeat p from 0 to 50
             packet[p]:=serial[0].rx
    '         serial[1].tx(packet[p])

      Bilge_Alarm:=packet[0]
      repeat p from 0 to 3
           byte[@starrpm][p]:=packet[p+1]
           byte[@portrpm][p]:=packet[p+5]
           byte[@starrevs][p]:=packet[p+9]
           byte[@portrevs][p]:=packet[p+13]
           byte[@sshiftcount][p]:=packet[p+17]
           byte[@pshiftcount][p]:=packet[p+21]
           byte[@mytimer[4]][p]:=packet[p+25]
           byte[@mytimer[3]][p]:=packet[p+29]
           byte[@mytimer[2]][p]:=packet[p+33]
           byte[@mytimer[1]][p]:=packet[p+37]
           byte[@xTilt][p]:=packet[p+43]
           byte[@ytilt][p]:=packet[p+47]

      STemp:=packet[41]
      PTemp:=packet[42]



     '------------   Calculate Port RPM and Revolutions ---------------------

      if starRPM>0
        SGear:=1
      elseif StarRPM<0
        SGear:=2
      else
        SGear:=0

      if PortRPM>0
        PGear:=1
      elseif PortRPM<0
        PGear:=2
      else
        PGear:=0

    Display_Bilges(Bilge_Alarm)    '-----Clear Old Needle and Numbers with Background Color---

    gr.color(0)
    gr.box(starx-30,starY+10,50,30)  ' Clear RPM Numbers
    gr.box(Portx-30,PortY+10,50,30)

    gr.box(starx-25,starY-25,57,10)  ' Clear Revolutin Odometer
    gr.box(Portx-25,PortY-25,57,10)

                                     ' Clear Shift Count
    gr.box(starx-25,starY-45,50,20)
    gr.box(Portx-25,PortY-45,50,20)

   
    gr.colorwidth(0,0)               ' Clear Needle
    gr.arc(PortX,PortY,PortR-16,PortR-16,23*(200-(||OldPortRPM)/2),23,4,3)      'Draw Starboard Needle
    gr.arc(StarX,StarY,StarR-16,StarR-16,23*(200-(||OldStarRPM)/2),23,4,3)
    OldStarRPM:=StarRPM
    OldPortRPM:=PortRPM

   
  

    '------ Draw Needles-----


    if PortRPM>0
        gr.colorwidth(1,0)
    else
        gr.colorwidth(2,0)                                                      'Set Gauge Color and Thickness
    gr.arc(PortX,PortY,PortR-16,PortR-16,23*(200-(||PortRPM)/2),23,4,3)      'Draw Starboard Needle
    if StarRPM>0
        gr.colorwidth(1,0)
    else
        gr.colorwidth(2,0)

    gr.arc(StarX,StarY,StarR-16,StarR-16,23*(200-(||StarRPM)/2),23,4,3)

     '---- Gauge Pivot Pins ---
    
       gr.colorwidth(1,12)            'Thick pivot pin like real gauge
       gr.plot(PortX,PortY)          'Draw Port Pivot
       gr.plot(StarX,StarY)          'Draw Starboard Pivot
         
  
    '---- Gauge RPM Numbers ---

    if StarRPM>0
        gr.colorwidth(2,0)
    else
        gr.colorwidth(1,0)
    gr.textmode(2,3,6,5)
    gr.text(StarX-5,StarY+25,Nucon.ToStr(StarRPM,%000_000_000_0_0_000100_01010)) 'Convert and Post Starboard Revolutions
    gr.finish
                                                            'Set Gauge Color and Thickness
    if PortRPM>0
        gr.colorwidth(2,0)
    else
        gr.colorwidth(1,0)
    gr.text(PortX-5,PortY+25,Nucon.ToStr(PortRPM,%000_000_000_0_0_000100_01010)) 'Convert and Post Starboard Revolutions
    gr.finish

    ' '--- Counter and Gear Displays---


    '  Note--> revolutions are divided by 3.5 due to hardware induced glitch caused by the protection hardware not switching fast enough
    gr.textmode(1,1,6,5)
    gr.colorwidth(2,0)
    gr.text(StarX,StarY-20,Nucon.ToStr(2*StarRevs/7,%000_000_000_0_0_001010_01010)) 'Convert and Post Starboard Revolutions
    gr.finish                                                                 'Finish graphic write beore next graphic
    gr.text(PortX,PortY-20,Nucon.ToStr(2*PortRevs/7,%000_000_000_0_0_001010_01010))  'Convert and Post Starboard Revolutions
    gr.finish       'Finish graphic write beore next graphic


    gr.color(0)

    case SGear        ' Display "R" for Reverse, "N" for Neutral or "F" for Forward Below Rev Count
    
      2:
         gr.text(StarX,StarY,@R)

      0:
         gr.text(StarX,StarY,@N)

      1:
         gr.text(StarX,StarY,@F)

    case PGear
    
      2:
         gr.text(PortX,PortY,@R)

      0:
         gr.text(PortX,PortY,@N)

      1:
         gr.text(PortX,PortY,@F)

    gr.color(2)
    gr.textmode(1,1,6,5)   
  
    gr.text(StarX-2,StarY-30,Nucon.ToStr(SShiftCount,%1010)) 'Convert and Post Starboard Shift Count
    gr.finish                                                                 'Finish graphic write beore next graphic
    gr.text(PortX-2,PortY-30,Nucon.ToStr(PShiftCount,%1010))  'Convert and Post Port Shift Count
    gr.finish                                                          'Finish graphic write beore next graphic
      ' ---------- Post Temp to Screen ------------------

    gr.color(0)
    gr.box(starx-25,starY-75,50,12)
    gr.box(Portx-25,PortY-75,50,12)
    gr.color(2)
    gr.textmode(1,1,6,9)
    gr.text(StarX,StarY-40,Nucon.ToStr(Stemp,10)) 'Convert and Post Starboard Temperatures
    gr.finish                                                                 'Finish graphic write beore next graphic
    gr.text(PortX,PortY-40,Nucon.ToStr(ptemp,10))  'Convert and Post Port Temperature
    gr.finish
    gr.textmode(1,1,6,5)
    gr.text(StarX+5,StarY-40,@deg)
    gr.text(PortX+5,PortY-40,@deg)

    '-     --------- Post Tilt ---------


   { Plot X tilt or pitch MM2125.MxTilt - Modify Scalar with sensor on}

    gr.color(0)
    gr.box(-9,-35,19,115)
    gr.colorwidth(1,30)
    gr.plot(0,(30-XTilt))
    gr.colorwidth(0,0)        
    gr.plot(0,80)
    gr.colorwidth(1,2)
    gr.line(0,-30)
    gr.colorwidth(0,0)
    gr.text(-3,(30-XTilt),nucon.tostr(||(XTilt),%1010))


   
   { Plot Y tilt or roll MM2125.MyTilt - Modify Scalar with sensor on}
    gr.color(0)
    gr.box(-100,-65,205,20)
    gr.colorwidth(1,30)
    gr.plot((YTilt),-55)
    gr.colorwidth(0,0)     
    gr.plot(-90,-55)
    gr.colorwidth(1,2)
    gr.line(90,-55)    
    gr.colorwidth(0,0)
    gr.text((YTilt)3-3,-55,nucon.tostr(||(YTilt),%1010))


 

'     ' ----------------- Post Output to Gauges ----------------------

    frqa := (255*(780-starrpm)/(780*2)) * gaugescale    ' calculate starboard duty cycle and update frqa register
    frqb := (255*(780-Portrpm)/(780*2)) * gaugescale    ' calculate zport duty cycle and update frqb register

 '-------------End of Main Calculation and Display Loop ------------------



PUB Display_bilges(BA)| j,z         ' ----- Check Bilges-----


if BA>0
        gr.color(0)
        gr.box(-130,-95,240,20)
        gr.colorwidth(1,0)
        gr.text(-95,-85,@Alarm)
        z:=1
        repeat j from 0 to 7    ' Post bilge #s with high pin

           if (BA & z)>0
             gr.colorwidth(1,15)
             gr.plot((-50+(j*15)),-85)
             gr.textmode(1,1,6,5)
             gr.colorwidth(0,0)
             gr.text((-50+(j*15)),-85,nucon.tostr(j,%1010))
           z:=z+z
else
           gr.color(0)
           gr.box(-130,-95,270,20)
           gr.colorwidth(2,0)
           gr.textmode(1,1,6,5)
           gr.text(-35,-85,@bilge)
           gr.text(53,-85,nucon.tostr(mytimer[4],%1010))
           gr.finish
           gr.text(68,-85,nucon.tostr(mytimer[3],%1010))
           gr.finish
           gr.text(83,-85,nucon.tostr(mytimer[2],%1010))
           gr.finish
           gr.text(98,-85,nucon.tostr(mytimer[1],%1010))
           gr.finish








DAT

tvparams                long    0               'status
                        long    1               'enable
                        long    %001_0101       'pins
                        long    %0000           'mode
                        long    0               'screen
                        long    0               'colors
                        long    x_tiles         'hc
                        long    y_tiles         'vc
                        long    10              'hx
                        long    1               'vx
                        long    0               'ho
                        long    0               'vo
                        long    0               'broadcast
                        long    0               'auralcog

ptitle                  byte    "Shaft",0               'text
psubtitle               byte    "RPM",0                 'text
pitch                   byte    "Pitch",0         'text
roll                    byte    "Roll",0         'text
alarm                   byte    "Bilge Alarm",0  'text
port                    byte    "P",0                'text
star                    byte    "S",0           'text 
bilge                   byte    "No Bilge Alarms, Runtime=",0     'text
pulse                   byte    "Pulse",0               'text
Comma                   byte    ",",0                   'text
None                    byte    "None Detected",0       'text

F                       byte    "F",0                   'text
N                       byte    "N",0                   'text
R                       byte    "R",0                   'text
Deg                     byte    $B0,"F",0
